package accountCC

const INTERNAL_CURRENCY_TYPE = "ANY"

// AccountCCDocType defines documents type to
// persist in state db
type AccountCCDocType string

// Possible constant value for supprted doc types
const (
	WalletDoc  AccountCCDocType = "wallet"  // Wallet records
	AccountDoc AccountCCDocType = "account" // Account records
)

// Type used to identify wallet or account types
// possible values: MAIN and ADDITIONAL
type AccountCCType string

// Enumerated types values
const (
	Main       AccountCCType = "MAIN"
	Additional AccountCCType = "ADDITIONAL"
)

func (t AccountCCType) String() string {
	return string(t)
}

func (s AccountCCDocType) String() string {
	return string(s)
}

type NewWallet struct {
	Type AccountCCType `json:"type,omitempty"`
}

type NewAccount struct {
	WalletID     string        `json:"wallet_id,omitempty"`
	Type         AccountCCType `json:"type,omitempty"`
	// todo validate CurrencyType
	CurrencyType string        `json:"currency_type,omitempty"`
}

type WalletWithAccounts struct {
	Wallet   Wallet    `json:"wallet,omitempty"`
	Accounts []Account `json:"accounts,omitempty"`
}

type GetAccountByCurrencyTypeArg struct {
	UserID       string `json:"user_id,omitempty"`
	// todo validate CurrencyType
	CurrencyType string `json:"currency_type,omitempty"`
}

type UserWalletsEnvelope struct {
	UserID  string                `json:"user_id,omitempty"`
	Wallets []*WalletWithAccounts `json:"wallet_list,omitempty"`
}

type AccountsEnvelope struct {
	Accounts *[]Account `json:"account_list,omitempty"`
}

type WalletsEnvelope struct {
	Wallets *[]Wallet `json:"wallet_list,omitempty"`
}
